------------------------------------------------------------------------------
-- Broker_TSMProfile - Displays the current TSM profile and lets you switch between profiles
------------------------------------------------------------------------------
-- Options.lua - Options
--
-- Author: Expelliarm5s / August 2022 / All Rights Reserved
--
-- Version 1.2.13
------------------------------------------------------------------------------
-- luacheck: ignore 212 globals DLAPI
-- luacheck: globals AceGUIWidgetLSMlists, max line length 160, ignore 212

local addonName, addon = ...
local Options = addon:NewModule("Options", "AceConsole-3.0")
local L = LibStub("AceLocale-3.0"):GetLocale(addonName)
local LSM = LibStub("LibSharedMedia-3.0")
local LibDBIcon = LibStub("LibDBIcon-1.0")
local WidgetLists = AceGUIWidgetLSMlists
--------------------------------------------------------------------------------------------------------

------------------------------------------------------------------------------
-- Settings

Options.defaults = {
	profile = {
	},
	global = {
		showMinimapButton = true,
		nwSound = "Small Chain",
		minimap = {
			hide = false,
		},
	},
}

------------------------------------------------------------------------------
-- Debug Stuff

function Options:DebugPrintf(...)
	if addon.isDebug then
		local status, res = pcall(format, ...)
		if status then
			addon:DebugLog("Opt~" .. res)
		end
	end
end

------------------------------------------------------------------------------
-- Addon Loading / Player Login/Logout

function Options:Login()
	Options:DebugPrintf("Login()")

	-- see https://wow.tools/files/#search=&page=1&sort=0&desc=asc
	if LSM then
		if not addon.isClassic then
			LSM:Register("sound", "Default", 567482)
			LSM:Register("sound", "Small Chain", 567577)
			LSM:Register("sound", "Bell Toll Alliance", 566564)
			LSM:Register("sound", "Bell Toll Horde", 565853)
			LSM:Register("sound", "Auction Window Close", 567499)
			LSM:Register("sound", "Quest Failed", 567459)
			LSM:Register("sound", "Fel Nova", 568582)
			LSM:Register("sound", "Simon Large Blue", 566076)
			LSM:Register("sound", "Simon Small Blue", 567002)
			LSM:Register("sound", "Portcullis Close", 566240)
			LSM:Register("sound", "PvP Flag Taken", 569200)
			LSM:Register("sound", "Sound Cannon", 566101)
			LSM:Register("sound", "Alarm 2", 567399)
		else
			LSM:Register("sound", "Default", SOUNDKIT.AUCTION_WINDOW_OPEN)
			LSM:Register("sound", "Small Chain", SOUNDKIT.PUT_DOWN_SMALL_CHAIN)
			LSM:Register("sound", "AH Bell", SOUNDKIT.AUCTION_WINDOW_CLOSE)
			LSM:Register("sound", "Simon Small Blue", SOUNDKIT.RAID_WARNING)
		end
	end

	-- reset to default
	if addon.db.global.nwSound == "Default" then
		addon.db.global.nwSound = "Small Chain"
	end
end

function Options.PlaySound(key)
	if LSM and key and LSM:Fetch("sound", key) then
		local sound = LSM:Fetch("sound", key)
		if sound == "Interface\\Quiet.ogg" then
			-- nix
			Options:DebugPrintf("Playing/1: silence")
		else
			if tonumber(sound) then
				if addon.isClassic then
					Options:DebugPrintf("PlaySound/2: %s", tostring(sound))
					PlaySound(sound, "master")
				else
					Options:DebugPrintf("PlaySoundFile/3: %s", tostring(sound))
					PlaySoundFile(sound, "master")
				end
			elseif type(sound) == "string" then
				if sound:match("^Sound") then
					Options:DebugPrintf("PlaySound/4: std sound")
					PlaySound(SOUNDKIT.AUCTION_WINDOW_OPEN, "master")
				else
					Options:DebugPrintf("PlaySoundFile/5: %s", sound)
					PlaySoundFile(sound, "master")
				end
			else
				Options:DebugPrintf("PlaySound/6: std sound")
				PlaySound(SOUNDKIT.AUCTION_WINDOW_OPEN, "master")
			end
		end
	else
		Options:DebugPrintf("PlaySound/7: std sound")
		PlaySound(SOUNDKIT.AUCTION_WINDOW_OPEN, "master")
	end
end

function Options.GetOptions(_, _, appName)
	if appName == addonName then

		local wowV, wowP = GetBuildInfo()
		local wowVersion = "|nGame: WoW, Flavor: " .. (addon.isClassic and "Vanilla/TBC/Wrath" or "Mainline") .. ", Version: " .. wowV .. ", Build: " .. wowP

		local soundWidget = "LSM30_Sound"
		if addon.isClassic then
			soundWidget = "LSM30_SoundClassic"
		end

		local options = {
			type = "group",
			name = addon.METADATA.NAME .. " (" .. addon.METADATA.VERSION .. ")",
			get = function(info)
					return addon.db.global[info[#info]] or ""
				end,
			set = function(info, value)
					addon.db.global[info[#info]] = value
					Options:DebugPrintf("OK~Set %s = %s", tostring(info[#info]), tostring(value))
					--if addon.GUI.display then
					--	addon.GUI.container:Reload()
					--end
				end,
			args = {
				desc0 = {
					type = "description",
					order = 0,
					name = "|cff99ccff-: by " .. GetAddOnMetadata(addonName, "Author") .. " :-|r|n|n" .. GetAddOnMetadata(addonName, "Notes"),
					fontSize = "medium",
				},
				desc001 = {
					type = "description",
					order = 0.01,
					name = wowVersion,
				},
				header100 = {
					type = "header",
					name = L["UI"],
					order = 1.00,
				},
				showMinimapButton = {
					type = "toggle",
					name = L["Show Minimap Button"],
					desc = L["If checked, the minimap button is present."],
					order = 1.001,
					width = "double",
					get = function(info) return addon.db.global[info[#info]] end,
					set = function(info, value)
							addon.db.global[info[#info]] = value
							if value then
								LibDBIcon:Show(addonName)
							else
								LibDBIcon:Hide(addonName)
							end
							Options:DebugPrintf("OK~Set %s = %s", tostring(info[#info]), tostring(value))
						end,
				},
				header200 = {
					type = "header",
					name = L["Misc."],
					order = 2.00,
				},
				nwSound = {
					type = "select",
					name = "Sound",
					desc = "Select the sound that is played if a profile was switched.",
					order = 2.4,
					width = "double",
					dialogControl = soundWidget,
					values = WidgetLists.sound,
					set = function(_, value)
						-- value = "Default"
						addon.db.global.nwSound = value
						Options:DebugPrintf("LSM: Key=%s", value)
						if LSM and value and LSM:Fetch("sound", value) then
							local sound = LSM:Fetch("sound", value)
							if sound then
								if type(sound) == "string" then
									Options:DebugPrintf("LSM: String=%s", sound)
								end
								if type(sound) == "number" then
									Options:DebugPrintf("LSM: Number=%s", tostring(sound))
								end
							end
						end
					end,
				},
			},
		}

		return options
	end
end

-- EOF
